@@ -1,5 +1,5 @@
 DrawVectors <-
-function(measured_data_,real_data_){
+function(measured_data_,real_data_){ #PODER CAMBIAR TAMAO DE LAS FLECHAS
 	
 	plot.new();
 	par(fg="white");
@@ -23,12 +23,12 @@ function(measured_data_,real_data_){
 	axis(side=2,pos=0,col="black",at=round(seq(length_y_min, 0, len=5),2),las=1,cex.axis=0.7,font.axis=3);
 	
     number_elements=length(real_data_)/2;
-	for(i in 1:number_elements){
+	for(i in 1:number_elements){                                     #si aado un paremetro ms da error en el number_elements
 		x=measured_data_[i,1]-real_data_[i,1];
 		y=measured_data_[i,2]-real_data_[i,2];
 
 		if((x!=0)&&(y!=0)){
-			arrows(measured_data_[i,1], measured_data_[i,2],real_data_[i,1],real_data_[i,2], length = 0.07, code = 2, col="blue");
+			arrows(measured_data_[i,1], measured_data_[i,2],real_data_[i,1],real_data_[i,2], length = 0,07, code = 2, col="blue");
 		}
 	}
 }
